==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/genericprojectmanager/kdevgenericmanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Generic Project Manager
Name[bg]=Най-общ манипулатор на проект
Name[bs]=Menadžer za generisanje projekta
Name[ca]=Gestor de projectes genèric
Name[ca@valencia]=Gestor de projectes genèric
Name[da]=Håndtering af generisk projekt
Name[de]=Allgemeine Projektverwaltung
Name[el]=Γενικευμένος διαχειριστής έργου
Name[en_GB]=Generic Project Manager
Name[es]=Gestor de proyectos genéricos
Name[et]=Üldine projektihaldur
Name[fi]=Yleinen projektihallinta
Name[fr]=Gestionnaire de projets générique
Name[gl]=Xestor de proxectos xenérico
Name[hu]=Általános projektkezelő
Name[it]=Gestore progetto generico
Name[ja]=一般プロジェクトマネージャ
Name[kk]=Жалпы жоба менеджері
Name[nb]=Generisk prosjektbehandler
Name[nds]=Allmeen Projektpleger
Name[nl]=Generieke projectenbeheerder
Name[pa]=ਆਮ ਪਰੋਜੈਕਟ ਮੈਨੇਜਰ
Name[pl]=Menadżer zwykłych projektów
Name[pt]=Gestor de Projectos Genérico
Name[pt_BR]=Gerenciador de projeto genérico
Name[ru]=Управление произвольными проектами
Name[sk]=Všeobecný správca projektov
Name[sl]=Splošni upravljalnik projektov
Name[sv]=Generell projekthantering
Name[tr]=Genel Proje Yönetici
Name[ug]=ئادەتتىكى قۇرۇلۇش باشقۇرغۇچ
Name[uk]=Звичайний засіб керування проектом
Name[x-test]=xxGeneric Project Managerxx
Name[zh_CN]=常规工程管理器
Name[zh_TW]=一般專案管理員
GenericName=Project Manager
GenericName[bg]=Управление на проекти
GenericName[bs]=Rukovodilac projekta
GenericName[ca]=Gestor de projectes
GenericName[ca@valencia]=Gestor de projectes
GenericName[cs]=Správce projektů
GenericName[da]=Projekthåndtering
GenericName[de]=Projektverwaltung
GenericName[el]=Διαχειριστής έργου
GenericName[en_GB]=Project Manager
GenericName[es]=Gestor de proyectos
GenericName[et]=Projektihaldur
GenericName[fi]=Projektinhallinta
GenericName[fr]=Gestionnaire de projets
GenericName[ga]=Bainisteoir Tionscadail
GenericName[gl]=Xestor de proxectos
GenericName[hu]=Projektkezelő
GenericName[it]=Gestore progetto
GenericName[ja]=プロジェクトマネージャ
GenericName[kk]=Жоба менеджері
GenericName[lv]=Projektu pārvaldnieks
GenericName[nb]=Prosjektbehandler
GenericName[nds]=Projektpleger
GenericName[nl]=Projectbeheerder
GenericName[nn]=Prosjekthandsamar
GenericName[pa]=ਪਰੋਜੈਕਟ ਮੈਨੇਜਰ
GenericName[pl]=Menadżer projektu
GenericName[pt]=Gestor de Projectos
GenericName[pt_BR]=Gerenciador de Projetos
GenericName[ro]=Gestionar de proiecte
GenericName[ru]=Управление проектами
GenericName[sk]=Správca projektu
GenericName[sl]=Upravljalnik projektov
GenericName[sv]=Projekthantering
GenericName[tr]=Proje Yönetici
GenericName[ug]=قۇرۇلۇش باشقۇرغۇچ
GenericName[uk]=Керування проектами
GenericName[x-test]=xxProject Managerxx
GenericName[zh_CN]=工程管理器
GenericName[zh_TW]=專案管理員
Comment=Allow KDevelop to manage generic projects
Comment[bg]=Рарешаване на KDevelop обобщено манипулиране на проекти
Comment[bs]=Dopusti KDevelopu da upravlja generičkim projektima
Comment[ca]=Permet a KDevelop gestionar projectes genèrics
Comment[ca@valencia]=Permet a KDevelop gestionar projectes genèrics
Comment[da]=Lader KDevelop håndtere generiske projekter
Comment[de]=Zum Verwalten allgemeiner Projekte in KDevelop
Comment[el]=Επιτρέπει στο KDevelop τη διαχείριση γενικευμένων έργων
Comment[en_GB]=Allow KDevelop to manage generic projects
Comment[es]=Permite que KDevelop gestione proyectos genéricos
Comment[et]=Võimaldab KDevelopil hallata üldisi projekte
Comment[fi]=Sallii KDevelop-ohjelman hallita yleisiä projekteja
Comment[fr]=Permettre à KDevelop de gérer des projets génériques
Comment[gl]=Permítelle a KDevelop xestionar proxectos xenéricos
Comment[hu]=Lehetővé teszi, hogy a KDevelop általános projekteket kezeljen
Comment[it]=Permette a KDevelop di gestire i progetti generici
Comment[ja]=KDevelop で一般的なプロジェクトを管理できるようにします
Comment[kk]=KDevelop-та жалпы жобаларды басқару мүмкіндігі
Comment[nb]=La KDevelop behandle generiske prosjekter
Comment[nds]=Lett KDevelop allmeen Projekten plegen
Comment[nl]=Sta toe dat KDevelop generieke projecten beheert
Comment[pl]=Zezwól KDevelopowi na zarządzanie zwykłymi projektami
Comment[pt]=Permite ao KDevelop gerir projectos genéricos
Comment[pt_BR]=Permite que o KDevelop gerencie projetos genéricos
Comment[ro]=Permite KDevelop să gestioneze proiecte generice
Comment[ru]=Позволяет управлять произвольными проектами в KDevelop
Comment[sk]=Povoliť KDevelopu spravovať všeobecné projekty
Comment[sl]=Omogoča, da KDevelop upravlja splošne projekte
Comment[sv]=Tillåter att KDevelop hanterar generella projekt
Comment[tr]=KDevelop uygulamasının genel projeleri yönetmesine izin ver
Comment[ug]=KDevelop نىڭ ئادەتتىكى قۇرۇلۇشلارنى باشقۇرۇشىغا ئىجازەت بېرىدۇ
Comment[uk]=За допомогою цього додатка можна увімкнути керування загальними проектами у KDevelop
Comment[x-test]=xxAllow KDevelop to manage generic projectsxx
Comment[zh_CN]=允许 KDevelop 管理常规工程
Comment[zh_TW]=讓 KDevelop 管理一般的專案
Icon=kdevelop
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevgenericmanager
X-KDE-PluginInfo-Name=KDevGenericManager
X-KDevelop-FileManager=None
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectFileManager,org.kdevelop.IGenericProjectManager
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Mode=GUI

==> kdevplatform-1.5.90.tar.xz: kdevplatform-1.5.90/plugins/genericprojectmanager/kdevgenericmanager.desktop.cmake <==
[Desktop Entry]
Type=Service
Name=Generic Project Manager
Name[bg]=Най-общ манипулатор на проект
Name[bs]=Menadžer za generisanje projekta
Name[ca]=Gestor de projectes genèric
Name[ca@valencia]=Gestor de projectes genèric
Name[da]=Håndtering af generisk projekt
Name[de]=Allgemeine Projektverwaltung
Name[el]=Γενικευμένος διαχειριστής έργου
Name[en_GB]=Generic Project Manager
Name[es]=Gestor de proyectos genéricos
Name[et]=Üldine projektihaldur
Name[fi]=Yleinen projektihallinta
Name[fr]=Gestionnaire de projets générique
Name[gl]=Xestor de proxectos xenérico
Name[hu]=Általános projektkezelő
Name[it]=Gestore progetto generico
Name[ja]=一般プロジェクトマネージャ
Name[kk]=Жалпы жоба менеджері
Name[nb]=Generisk prosjektbehandler
Name[nds]=Allmeen Projektpleger
Name[nl]=Generieke projectenbeheerder
Name[pa]=ਆਮ ਪਰੋਜੈਕਟ ਮੈਨੇਜਰ
Name[pl]=Menadżer zwykłych projektów
Name[pt]=Gestor de Projectos Genérico
Name[pt_BR]=Gerenciador de projeto genérico
Name[ru]=Управление произвольными проектами
Name[sk]=Všeobecný správca projektov
Name[sl]=Splošni upravljalnik projektov
Name[sv]=Generell projekthantering
Name[tr]=Genel Proje Yönetici
Name[ug]=ئادەتتىكى قۇرۇلۇش باشقۇرغۇچ
Name[uk]=Звичайний засіб керування проектом
Name[x-test]=xxGeneric Project Managerxx
Name[zh_CN]=常规工程管理器
Name[zh_TW]=一般專案管理員
GenericName=Project Manager
GenericName[bg]=Управление на проекти
GenericName[bs]=Rukovodilac projekta
GenericName[ca]=Gestor de projectes
GenericName[ca@valencia]=Gestor de projectes
GenericName[cs]=Správce projektů
GenericName[da]=Projekthåndtering
GenericName[de]=Projektverwaltung
GenericName[el]=Διαχειριστής έργου
GenericName[en_GB]=Project Manager
GenericName[es]=Gestor de proyectos
GenericName[et]=Projektihaldur
GenericName[fi]=Projektinhallinta
GenericName[fr]=Gestionnaire de projets
GenericName[ga]=Bainisteoir Tionscadail
GenericName[gl]=Xestor de proxectos
GenericName[hu]=Projektkezelő
GenericName[it]=Gestore progetto
GenericName[ja]=プロジェクトマネージャ
GenericName[kk]=Жоба менеджері
GenericName[lv]=Projektu pārvaldnieks
GenericName[nb]=Prosjektbehandler
GenericName[nds]=Projektpleger
GenericName[nl]=Projectbeheerder
GenericName[nn]=Prosjekthandsamar
GenericName[pa]=ਪਰੋਜੈਕਟ ਮੈਨੇਜਰ
GenericName[pl]=Menadżer projektu
GenericName[pt]=Gestor de Projectos
GenericName[pt_BR]=Gerenciador de Projetos
GenericName[ro]=Gestionar de proiecte
GenericName[ru]=Управление проектами
GenericName[sk]=Správca projektu
GenericName[sl]=Upravljalnik projektov
GenericName[sv]=Projekthantering
GenericName[tr]=Proje Yönetici
GenericName[ug]=قۇرۇلۇش باشقۇرغۇچ
GenericName[uk]=Керування проектами
GenericName[x-test]=xxProject Managerxx
GenericName[zh_CN]=工程管理器
GenericName[zh_TW]=專案管理員
Comment=Allow KDevelop to manage generic projects
Comment[bg]=Рарешаване на KDevelop обобщено манипулиране на проекти
Comment[bs]=Dopusti KDevelopu da upravlja generičkim projektima
Comment[ca]=Permet al KDevelop gestionar projectes genèrics
Comment[ca@valencia]=Permet a KDevelop gestionar projectes genèrics
Comment[da]=Lader KDevelop håndtere generiske projekter
Comment[de]=Zum Verwalten allgemeiner Projekte in KDevelop
Comment[el]=Επιτρέπει στο KDevelop τη διαχείριση γενικευμένων έργων
Comment[en_GB]=Allow KDevelop to manage generic projects
Comment[es]=Permite que KDevelop gestione proyectos genéricos
Comment[et]=Võimaldab KDevelopil hallata üldisi projekte
Comment[fi]=Sallii KDevelop-ohjelman hallita yleisiä projekteja
Comment[fr]=Permettre à KDevelop de gérer des projets génériques
Comment[gl]=Permítelle a KDevelop xestionar proxectos xenéricos
Comment[hu]=Lehetővé teszi, hogy a KDevelop általános projekteket kezeljen
Comment[it]=Permette a KDevelop di gestire i progetti generici
Comment[ja]=KDevelop で一般的なプロジェクトを管理できるようにします
Comment[kk]=KDevelop-та жалпы жобаларды басқару мүмкіндігі
Comment[nb]=La KDevelop behandle generiske prosjekter
Comment[nds]=Lett KDevelop allmeen Projekten plegen
Comment[nl]=Sta toe dat KDevelop generieke projecten beheert
Comment[pl]=Zezwól KDevelopowi na zarządzanie zwykłymi projektami
Comment[pt]=Permite ao KDevelop gerir projectos genéricos
Comment[pt_BR]=Permite que o KDevelop gerencie projetos genéricos
Comment[ro]=Permite KDevelop să gestioneze proiecte generice
Comment[ru]=Позволяет управлять произвольными проектами в KDevelop
Comment[sk]=Povoliť KDevelopu spravovať všeobecné projekty
Comment[sl]=Omogoča, da KDevelop upravlja splošne projekte
Comment[sv]=Tillåter att KDevelop hanterar generella projekt
Comment[tr]=KDevelop uygulamasının genel projeleri yönetmesine izin ver
Comment[ug]=KDevelop نىڭ ئادەتتىكى قۇرۇلۇشلارنى باشقۇرۇشىغا ئىجازەت بېرىدۇ
Comment[uk]=За допомогою цього додатка можна увімкнути керування загальними проектами у KDevelop
Comment[x-test]=xxAllow KDevelop to manage generic projectsxx
Comment[zh_CN]=允许 KDevelop 管理常规工程
Comment[zh_TW]=讓 KDevelop 管理一般的專案
Icon=kdevelop
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevgenericmanager
X-KDE-PluginInfo-Name=KDevGenericManager
X-KDevelop-FileManager=None
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Project
X-KDevelop-Interfaces=org.kdevelop.IProjectFileManager,org.kdevelop.IGenericProjectManager
X-KDE-PluginInfo-Author=Milian Wolff
X-KDE-PluginInfo-Category=Project Management
X-KDevelop-Mode=GUI
